*******************************
Publications Using ``climpred``
*******************************

Below is a list of publications that have made use of ``climpred`` in their analysis. You can nod
to ``climpred``, e.g., in your acknowledgements section to help build the community. The main
developers of the package intend to release a manuscript documenting ``climpred`` in 2020 with a
citable DOI, so this can be referenced in the future.

Feel free to open a `Pull Request <contributing.html>`_ to add your publication to the list!

2021
####

* Spring, A., Dunkl, I., Li, H., Brovkin, V., & Ilyina, T. (2021). Trivial improvements
  of predictive skill due to direct reconstruction of global carbon cycle.
  Earth System Dynamics Discussions, 1–36. https://doi.org/10/gh3tn3


2020
####

* Brady, R.X., Lovenduski, N.S., Yeager, S.G., Long, M.C., Lindsay, K (2020). Skillful multiyear
  predictions of ocean acidification in the California Current System. *Nature Communications*,
  11, 2166. https://doi.org/10.1038/s41467-020-15722-x
* Spring, A., Ilyina, T. (2020). Predictability horizons in theglobal carbon cycle inferred
  from a perfect-model framework. *Geophysical Research Letters*, 47, e2019GL085311.
  https://doi.org/10.1029/2019GL085311
* Krumhardt, K. M., Lovenduski, N. S., Long, M. C., Luo, J. Y., Lindsay, K., Yeager, S., &
  Harrison, C. (2020). Potential Predictability of Net Primary Production in the Ocean.
  *Global Biogeochemical Cycles*, 34(6), e2020GB006531. https://doi.org/10/gg9ss8
